@@ -61,13 +61,17 @@ class Server(object):
     """
     
     def __init__(self, uri='http://127.0.0.1:5984', uuid_batch_count=DEFAULT_UUID_BATCH_COUNT, 
-            transport=None):
+            transport=None, use_proxy=False, min_size=0, max_size=4, pool_class=None):
         """ constructor for Server object
         
         @param uri: uri of CouchDb host
         @param uuid_batch_count: max of uuids to get in one time
         @param transport: an transport instance from :mod:`restkit.transport`. Can be used
                 to manage authentification to your server or proxy.
+        @param use_proxy: boolean, default is False, if you want to use a proxy
+        @param min_size: minimum number of connections in the pool
+        @param max_size: maximum number of connection in the pool
+        @param pool_class: custom pool class
         """
         
         if not uri or uri is None:
@@ -75,10 +79,15 @@ class Server(object):
 
         self.uri = uri
         self.transport = transport
+        self.use_proxy = use_proxy
+        self.min_size = min_size
+        self.max_size = max_size
+        self.pool_class = pool_class
         self.uuid_batch_count = uuid_batch_count
         self._uuid_batch_count = uuid_batch_count
         
-        self.res = CouchdbResource(uri, transport=transport)
+        self.res = CouchdbResource(uri, transport=transport, use_proxy=use_proxy,
+            min_size=min_size, max_size=max_size, pool_class=pool_class)
         self.uuids = []
         
     def info(self, _raw_json=False):
@@ -556,7 +565,7 @@ class Database(object):
         This is a shorthand to view function.
         """
         return View(self, '_all_docs', wrapper=wrapper)(**params)
-    iter_documents = documents    
+    iterdocuments = documents
 
     def put_attachment(self, doc, content, name=None, content_type=None, 
         content_length=None):
@@ -686,7 +695,7 @@ class Database(object):
        self.delete_doc(docid)
 
     def __iter__(self):
-        return self.iterdocuments()
+        return self.documents().iterator()
         
     def __nonzero__(self):
         return (len(self) > 0)
@@ -774,7 +783,7 @@ class ViewResults(object):
 
     def all(self):
         """ return list of all results """
-        return list(self)
+        return list(self.iterator())
 
     def count(self):
         """ return number of returned results """
